@@ -50,8 +50,8 @@ static const char * __vid_help  =
   "vid (XVisual ID) -  ID of the associated X Visual.";
 static const char * __vt_help  =
   "vt (XVisual Type) -  Type of the associated X Visual. "
-  "Possible X visual types are 'tc', 'dc', 'pc', 'sc', 'gs', 'sg', '.' "
-  "which means TrueColor, DirectColor, PseudoColor, StaticColor, GrayScale, "
+  "Possible X visual types are 'tc', 'dc', 'pc', 'sc', 'gs', 'sg' and '.' "
+  "which mean TrueColor, DirectColor, PseudoColor, StaticColor, GrayScale, "
   "StaticGray and None, respectively.";
 static const char * __bfs_help =
   "bfs (buffer size) - Number of bits per color in the color buffer.";
@@ -73,16 +73,16 @@ static const char * __st_help =
   "buffers that are rendered to in stereo.  '-' if this is not supported.";
 static const char * __rs_help =
   "rs (Red size) - Number of bits per color used for red. "
-  "(Undefined for configurations that use color indexing.)";
+  "Undefined for configurations that use color indexing.";
 static const char * __gs_help =
   "gs (Green size) - Number of bits per color used for green. "
-  "(Undefined for configurations that use color indexing.)";
+  "Undefined for configurations that use color indexing.";
 static const char * __bs_help =
   "bs (Blue size) - Number of bits per color used for blue. "
-  "(Undefined for configurations that use color indexing.)";
+  "Undefined for configurations that use color indexing.";
 static const char * __as_help =
   "as (Alpha size) - Number of bits per color used for alpha. "
-  "(Undefined for configurations that use color indexing.)";
+  "Undefined for configurations that use color indexing.";
 static const char * __aux_help =
   "aux (Auxiliary buffers) - Number of available auxiliary color buffers.";
 static const char * __dpt_help =
@@ -826,7 +826,7 @@ GtkTextBuffer *ctk_glx_create_help(GtkTextTagTable *table,
     ctk_help_para(b, &i,
                   "This is the list of GLX extensions that are supported by "
                   "both the client (libraries) and server (GLX extension to "
-                  "the X Server.)"
+                  "the X Server)."
                   );
 
     ctk_help_heading(b, &i, "Server GLX Vendor String");
